@@ -35,11 +35,12 @@ fetch_teams_afl <- function(comp){
   
   
   df <- teams %>%
-    stats::na.omit() %>%
     dplyr::select(
       "id", "abbreviation",
-      "name", "teamType"
-    )
+      "name", "teamType",
+      "club.id","club.providerId","club.name","club.abbreviation","club.nickname"
+    ) %>%
+    stats::na.omit()
   
   type <- dplyr::case_when(
     comp == "AFLM" ~ "MEN",
@@ -487,6 +488,7 @@ fetch_squad_afl <- function(teamId, team, season, compSeasonId) {
     )
   )
 
+  if (httr::http_error(resp)) return(NULL)
   cont <- parse_resp_afl(resp)
 
   df <- dplyr::as_tibble(cont$squad$players)
