@@ -3,14 +3,13 @@ test_that("Squiggle API queries work", {
   testthat::skip_on_cran()
 
 
-  expect_type(fetch_squiggle_data(), "list")
+  expect_error(fetch_squiggle_data())
   expect_type(fetch_squiggle_data("sources"), "list")
-  expect_type(fetch_squiggle_data("tips"), "list")
-  expect_type(fetch_squiggle_data("games"), "list")
+  expect_type(fetch_squiggle_data("tips", year = 2022), "list")
+  expect_type(fetch_squiggle_data("games", year = 2022), "list")
 
   # Test errors
   expect_error(fetch_squiggle_data("a"))
-  expect_error(fetch_squiggle_data("games", years = 2018))
   expect_error(fetch_squiggle_data(1))
   expect_error(fetch_squiggle_data("a"))
 })
@@ -51,11 +50,6 @@ test_that("Squiggle API optional arguments work", {
     "list"
   )
 
-  expect_error(fetch_squiggle_data(
-    query = "tips",
-    x = "",
-    year = 2018
-  ))
 })
 
 # Legacy Tests - to be removed eventually --------------------------------------
@@ -65,7 +59,7 @@ test_that("get_squiggle works", {
   testthat::skip_on_cran()
 
 
-  expect_warning(dat <- get_squiggle_data())
+  expect_warning(dat <- get_squiggle_data("games", year = 2024))
   expect_type(dat, "list")
 
   # Test errors
